<?php

/******************************************************************************
 * 取得した xml をパースするクラス
 *****************************************************************************/
class SimpleAmazonXmlParse {

	private $cache;
	private $access_key;
	private $private_key;

	/**
	 * @param	none
	 * @return	object $this
	 */
	function __construct() {

		global $simple_amazon_settings;

		$this->access_key = & $simple_amazon_settings['accesskeyid'];
		$this->private_key = & $simple_amazon_settings['secretaccesskey'];
		$this->cache = new SimpleAmazonCacheControl();

	}

	/**
	 * @brief	Amazonのレスポンスを返す
	 * @param	array $arr
	 * @rerturn	object $parsedata
	 */
	public function getamazonxml( $arr ) {

		$method = "GET";
		$host = "ecs.amazonaws." . $arr['domain'];
		$uri = "/onca/xml";

		if( !$this->access_key || !$this->private_key ) {
			return false;
		}

		$params = array(
			'Service'			=> 'AWSECommerceService',
			'AWSAccessKeyId'	=> $this->access_key,
			'Timestamp'			=> gmdate("Y-m-d\TH:i:s\Z"),
			'Version'			=> '2010-07-08',
			'ContentType'		=> 'text/xml',
			'Operation'			=> 'ItemLookup',
			'MerchantId'		=> 'All',
			'Condition'			=> 'All'
		);

		$params['ItemId']			= $arr['ItemId'];
		$params['ResponseGroup']	= $arr['ResponseGroup'];

		if( $arr['AssociateTag'] != '' ) $params['AssociateTag'] = $arr['AssociateTag'];
		if( array_key_exists( 'MarketplaceDomain', $arr ) ) $params['MarketplaceDomain'] = $arr['MarketplaceDomain'];

		// sort the parameters
		ksort($params);

		// create the canonicalized query
		$canonicalized_query = array();
		foreach ($params as $param=>$value) {
			$param = str_replace("%7E", "~", rawurlencode($param));
			$value = str_replace("%7E", "~", rawurlencode($value));
			$canonicalized_query[] = $param."=".$value;
		}
		$canonicalized_query = implode("&", $canonicalized_query);

		// create the string to sign
		$string_to_sign = $method."\n".$host."\n".$uri."\n".$canonicalized_query;

		// calculate HMAC with SHA256 and base64-encoding
		$signature = base64_encode(hash_hmac("sha256", $string_to_sign, $this->private_key, true));

		// create request
		$xmlFeed = "http://".$host.$uri."?".$canonicalized_query."&Signature=".$signature;

		// --- Set an ID for this cache ---
		$id = $arr['domain'] . $params['ItemId'];

		// Check to see if there is a valid cache of xml
		if ($xmldata = $this->cache->get( $id )) {  // there is a cache, so parse cached xml
//			echo "<!-- read cache -->";
		}else{
//			echo "<!-- read feed -->";
			$xmldata = $this->cache->save( $xmlFeed, $id );
		}
		$parsedata = simplexml_load_string( $xmldata );

		return $parsedata;

	}

}


/******************************************************************************
 * ISBN13とISBN10を相互に変換するクラス
 *****************************************************************************/
class CalcISBNLibrary {

	public function calc_chkdgt_mod10( $val ){
		$f = 0;
		$g = 0;
		$k = 0;

		$mod_res = explode( ',',chunk_split( $val, 1, ',' ) );
		for( $ii=count( $mod_res )-1; $ii>-1; $ii-- ){
			$x=intval( $mod_res[$ii] );
			if( $f == 0 ){
				$k += $x;
				$f = 1;
			} else {
				$g += $x;
				$f = 0;
			}
		}
		$chkdgt = substr( strval( 10-intval( substr( strval( $g*3 + $k ), -1 ) ) ),-1 );
		return $val.$chkdgt;
	}

	public function calc_chkdgt_isbn10( $val ){
		$g = 0;

		$mod_res = explode( ',',chunk_split( $val, 1, ',' ) );
		for( $ii=count( $mod_res )-1; $ii>-1; $ii-- ){
			$x=intval( $mod_res[$ii] );
			$g += $x*( 11-( $ii+1 ));
		}

		$checksum = (( (int)( $g/11 ) )+1)*11 - $g;

		if( $checksum == 11 ){
			$chkdgt = 0;
		} elseif( $checksum == 10 ){
			$chkdgt = 'X';
		} else {
			$chkdgt = $checksum;
		}

		return $val.$chkdgt;
	}

}
?>